==> kdebase-1.90.tar.bz2: kdebase-1.90/kicker/externalapplets/example/main.cpp <==
/*****************************************************************

Copyright (c) 1996-2000 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <kapp.h>
#include <kcmdlineargs.h>
#include <klocale.h>

#include "example.h"

int main( int argc, char ** argv )
{
  KCmdLineArgs::init(argc, argv, "exampleapplet", I18N_NOOP("Example applet for kicker."), "v0.1.0" );
  KApplication a;
  
  ExampleApplet applet( 0, "example applet");
  a.setMainWidget( &applet );
  applet.init( argc, argv);
  return a.exec();
}

==> kdebase-1.91.tar.bz2: kdebase-1.91/kicker/externalapplets/example/main.cpp <==
/*****************************************************************

Copyright (c) 1996-2000 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <kapp.h>
#include <kcmdlineargs.h>
#include <klocale.h>

#include "example.h"

static KCmdLineOptions options[] =
{
   { "appletId <id>", I18N_NOOP("For internal use only."), "" },
   { 0,0,0 }
};


int main( int argc, char ** argv )
{
  KCmdLineArgs::init(argc, argv,
                     "exampleapplet",
                     I18N_NOOP("Example applet for kicker."),
                     "v0.1.0" );
  KCmdLineArgs::addCmdLineOptions( options ); // add our own options.
  KApplication::addCmdLineOptions();

  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

  KApplication a;
  
  ExampleApplet applet( 0, "example applet");
  a.setMainWidget( &applet );
  if(applet.dock(args->getOption("appletId")))
     return a.exec();

  return 1;
}
